import {computed, reactive} from "vue";
import {net} from "frontend/wailsjs/go/models";
import IOCountersStat = net.IOCountersStat;
import {GetNetworkCounter} from "frontend/wailsjs/go/system/InfoUtils";

let network = reactive({
    counter: {
        data: <IOCountersStat[]>[],
        interval: <any>undefined
    },
    sumCounter: {
        rate: {
            recv: 0,
            sent: 0,
        },
        data: <IOCountersStat>{},
        interval: <any>undefined
    }
})


function loopNetworkSumCounter(){
    clearInterval(network.sumCounter.interval)
    function loop(){
        GetNetworkCounter(true).then(result=> {
            network.sumCounter.rate.recv = result[0].bytesRecv - network.sumCounter.data.bytesRecv
            network.sumCounter.rate.sent = result[0].bytesSent - network.sumCounter.data.bytesSent

            network.sumCounter.data = result[0]
        })
        network.sumCounter.interval = setTimeout(()=>{
            loop()
        },1000)
    }
    loop()
}


export function useNetworkSumCounter(){
    if(network.sumCounter.interval == null){
        loopNetworkSumCounter()
    }

    return computed(()=> network.sumCounter.data)
}

export function useNetworkSumRate(){
    if(network.sumCounter.interval == null){
        loopNetworkSumCounter()
    }

    return computed(()=> network.sumCounter.rate)
}
